#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: views.py 9166 2013-05-16 06:52:28Z Eric $
#
# Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Eric $
# $Date: 2013-05-16 06:52:28 +0000 (週四, 16 五月 2013) $
# $Revision: 9166 $

from django.urls import reverse
from django.http import HttpResponseRedirect

def getIndex(request):
    """
    Redirect to django admin homepage.

    @param slug Newsletter slug.
    @param request Request instance.
    """
    from Theophrastus.AdvancedMailServer import AdvancedMailServer
    
    server = AdvancedMailServer()
    server.start()
    
    return HttpResponseRedirect(reverse('admin:index'))
